#!/bin/bash

# Copyright Michael Verret <axxium.zenlnx@gmail.com>. This program is
# free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your
# option) any later version. Please take a look at 
# http://www.gnu.org/copyleft/gpl.htm

# Zenwalk Gnu/Linux build script written for "sdl_docs"
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/SDL-1.2-FAQ.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/sdldoc-html.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/sdldoc-man3.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/SDL_image_html.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/SDL_mixer_html.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/SDL_net_html.tar.gz
# Source URL: http://internap.dl.sourceforge.net/sourceforge/libsdl/SDL_ttf_html.tar.gz
# Package Maintainer: Michael Verret (AxXium) axxium.zenlnx@gmail.com


#------------------( Unique Package Variables )


SOFTNAME='sdl_docs'
SOFTVERSION='1.2'
PKGVERSION="52.1"
ARCH='noarch'
PACKAGE="$SOFTNAME-$SOFTVERSION-$ARCH-$PKGVERSION"
BUILDIR=$(pwd)
DEST="$BUILDIR/$PACKAGE"


#------------------( Define The Sources )


SDLFAQSOURCE='SDL-1.2-FAQ'
SDLDOCHTMLSOURCE='sdldoc-html'
SDLDOCMAN3SOURCE='sdldoc-man3'
SDLIMAGEHTMLSOURCE='SDL_image_html'
SDLMIXERHTMLSOURCE='SDL_mixer_html'
SDLNETHTMLSOURCE='SDL_net_html'
SDLTTFHTMLSOURCE='SDL_ttf_html'


#------------------( Make Sure That We Have Everything )


for file in {$SDLFAQSOURCE.tar.gz,$SDLDOCHTMLSOURCE.tar.gz,$SDLDOCMAN3SOURCE.tar.gz,$SDLIMAGEHTMLSOURCE.tar.gz,$SDLMIXERHTMLSOURCE.tar.gz,$SDLNETHTMLSOURCE.tar.gz,$SDLTTFHTMLSOURCE.tar.gz} ; do
  echo -n "$file :"
  if [ -e $file ]; then
    echo " OK"
  else
    echo " MISSING !"
    exit 1
  fi
done


#------------------( Make Sure We Have Clean Place To Work )


cd $BUILDIR
  rm -rf  $DEST $DEST.dep $DEST.md5 $DEST.tgz \
    $PACKAGE $PACKAGE.dep $PACKAGE.md5 1>/dev/null 2>&1


#------------------( Create Common Directories )


mkdir -p $DEST/install
mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION
mkdir -p $DEST/usr/share/applications
mkdir -p $DEST/usr/share/icons/hicolor/48x48/apps


#------------------( Install SDL-1.2-FAQ )


( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION ; tar -xvzf $BUILDIR/$SDLFAQSOURCE.tar.gz )


#------------------( Install SDL_image_html )


mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_image
( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_image/ ; tar -xvzf $BUILDIR/$SDLIMAGEHTMLSOURCE.tar.gz )


cat <<E0F > $DEST/usr/share/applications/SDL_image_docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/sdl_docs-1.2/sdl_image/html/SDL_image.html
Icon=sdl_docs
Type=Application
Categories=Application;Development;
Name=SDL_image Documentation
GenericName=Documentation for developing with SDL_image
E0F


#------------------( Install SDL_mixer_html )


mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_mixer
( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_mixer/ ; tar -xvzf $BUILDIR/$SDLMIXERHTMLSOURCE.tar.gz )

cat <<E1F > $DEST/usr/share/applications/SDL_mixer_docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/sdl_docs-1.2/sdl_mixer/html/SDL_mixer.html
Icon=sdl_docs
Type=Application
Categories=Application;Development;
Name=SDL_mixer Documentation
GenericName=Documentation for developing with SDL_mixer
E1F


#------------------( Install SDL_net_html )


mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_net
( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_net/ ; tar -xvzf $BUILDIR/$SDLNETHTMLSOURCE.tar.gz )

cat <<E2F > $DEST/usr/share/applications/SDL_net_docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/sdl_docs-1.2/sdl_net/html/SDL_net.html
Icon=sdl_docs
Type=Application
Categories=Application;Development;
Name=SDL_net Documentation
GenericName=Documentation for developing with SDL_net
E2F


#------------------( Install SDL_ttf_html )


mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_ttf
( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_ttf/ ; tar -xvzf $BUILDIR/$SDLTTFHTMLSOURCE.tar.gz )

cat <<E3F > $DEST/usr/share/applications/SDL_ttf_docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/sdl_docs-1.2/sdl_ttf/html/SDL_ttf.html
Icon=sdl_docs
Type=Application
Categories=Application;Development;
Name=SDL_ttf Documentation
GenericName=Documentation for developing with SDL_ttf
E3F


#------------------( Install sdldoc-html )


mkdir -p $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_doc
( cd $DEST/usr/doc/$SOFTNAME-$SOFTVERSION/sdl_doc/ ; tar -xvzf $BUILDIR/$SDLDOCHTMLSOURCE.tar.gz )

cat <<E4F > $DEST/usr/share/applications/SDL_docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/sdl_docs-1.2/sdl_doc/html/index.html
Icon=sdl_docs
Type=Application
Categories=Application;Development;
Name=SDL Documentation
GenericName=Documentation for developing with SDL
E4F


#------------------( Install sdldoc-man3 )


mkdir -p $DEST/usr/man
( cd $DEST/usr/man/ ; tar -xvzf $BUILDIR/$SDLDOCMAN3SOURCE.tar.gz )
( cd $DEST/usr/man/man3/ ; gzip -9 *.3 )


#------------------( Add SDL Icon )


cp $BUILDIR/sdl_docs.png $DEST/usr/share/icons/hicolor/48x48/apps/


#------------------( Add Slack-desc )


cat <<E5F > $DEST/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
sdl_docs: sdl_docs (Development documentation for SDL)
sdl_docs:
sdl_docs: This package contains documentation useful for people
sdl_docs: insterested in developing software with SDL aka the
sdl_docs: 'Simple DirectMedia Layer'. The included documentation
sdl_docs: covers SDL, SDL_image, SDL_mixer, SDL_net, SDL_ttf and
sdl_docs: provides some additional man pages.
sdl_docs:
sdl_docs:
sdl_docs:
sdl_docs:
E5F


#------------------( Add Buildscript )


mkdir -p $DEST/usr/src/$SOFTNAME-$SOFTVERSION
  ( cd $BUILDIR ; cp build-$SOFTNAME.sh $DEST/usr/src/$SOFTNAME-$SOFTVERSION/ )


#------------------( Create Dependency File )


touch $BUILDIR/$PACKAGE.dep


#------------------( Compress The Package )


( cd $DEST ; makepkg -l y -c n $BUILDIR/$PACKAGE.tgz )


#------------------( Calculate The MD5 Sum )

( cd $BUILDIR ; md5sum $PACKAGE.tgz > $PACKAGE.md5 )
( cd $BUILDIR ; rm -rf $DEST )
